@@ -52,7 +52,6 @@ sub new {
 sub install_deps {
     my $self = shift;
     my $name = shift;
-    my $cross = shift;
     my @pkgs = @_;
 
     my $status = 0;
@@ -95,8 +94,6 @@ sub install_deps {
 	}
     }
 
-    $self->cleanup_apt_archive();
-
     return $status;
 }
 
